/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) INRIA - Allan CORNET
* 
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at    
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*--------------------------------------------------------------------------*/
#ifndef __SPLASHSCREEN_H__
#define __SPLASHSCREEN_H__

#include "dynlib_scilab_windows.h"

/* Display splashscreen */
SCILAB_WINDOWS_IMPEXP void splashScreen(void);

#endif /* __SPLASHSCREEN_H__ */
/*--------------------------------------------------------------------------*/